"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const util_1 = require("../util");
exports.default = {
    tagName: 'colgroup',
    getCategories(element) {
        return [];
    },
    validateContext(element) {
        const result = [];
        if (element.parentElement) {
            if ((0, util_1.isNotTag)('table', element.parentElement)) {
                result.push({
                    expect: 'as a child of an table element',
                    got: (0, util_1.getNodeInfo)(element.parentElement),
                    target: element
                });
            }
            for (let next = element; (next = next.nextElementSibling);) {
                if ((0, util_1.isTag)('caption', next)) {
                    result.push({
                        expect: 'after any caption elements',
                        target: element
                    });
                    break;
                }
            }
            for (let prev = element; (prev = prev.previousElementSibling);) {
                if ((0, util_1.isTag)('thead|tbody|tfoot|tr', prev)) {
                    result.push({
                        expect: 'before any thead, tbody, tfoot, and tr elements',
                        target: element
                    });
                    break;
                }
            }
        }
        return result;
    },
    validateContent(element) {
        const result = [];
        if (element.hasAttribute('span')) {
            if (element.childNodes.length) {
                result.push({ expect: 'empty' });
            }
        }
        else {
            result.push(...(0, util_1.validateChildrenSequence)({
                desc: 'zero or more col and template elements',
                sequence: [['col|template', '*']]
            }, element));
        }
        return result;
    }
};
//# sourceMappingURL=colgroup.js.map