"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const dom_1 = require("@mewjs/dom");
const util_1 = require("../util");
exports.default = {
    tagName: 'option',
    getCategories(element) {
        return [];
    },
    validateContext(element) {
        const result = [];
        if (element.parentElement
            && (0, util_1.isNotTag)('select|datalist|optgroup', element.parentElement)) {
            result.push({
                expect: 'as a child of a select element, a datalist element or an optgroup element',
                got: (0, util_1.getNodeInfo)(element.parentElement),
                target: element
            });
        }
        return result;
    },
    validateContent(element) {
        const result = [];
        const { children } = element;
        if (element.hasAttribute('label')
            && element.hasAttribute('value')) {
            if (element.childNodes.length) {
                result.push({ expect: 'empty' });
            }
        }
        if (element.hasAttribute('label')
            && !element.hasAttribute('value')) {
            if (children.filter(dom_1.isTag).length > 0) {
                result.push({ expect: 'text' });
            }
        }
        if (!element.hasAttribute('label')) {
            if (!(element.childNodes.length === 1
                && element.childNodes[0].nodeType === 3
                && (0, util_1.isNot)('inter-element whitespace', element.childNodes[0]))) {
                result.push({
                    expect: 'text that is not inter-element whitespace',
                    target: element
                });
            }
        }
        return result;
    }
};
//# sourceMappingURL=option.js.map